/*------------------------------*/
/*  Intro a la programac de     */
/*  juegos, por Nacho Cabanes   */
/*                              */
/*   ElementoGraf.cpp:          */
/*     Clase "elemento grfico" */
/*       para Allegro           */
/*     Fichero de desarrollo    */
/*                              */
/*     Parte de "MiniMiner"     */
/*                              */
/*  Ejemplo:                    */
/*    Primer acercamiento a     */
/*    "MiniMiner"               */
/*                              */
/*  Comprobado con:             */
/*  - DevC++ 4.9.9.2(gcc 3.4.2) */
/*    y Allegro 4.03 - WinXP    */
/*------------------------------*/

#include "ElementoGraf.h"

#ifdef __cplusplus
    #include <cstdlib>
#else
    #include <stdlib.h>
#endif

#include <allegro.h>

/** moverA: cambia la posicion del elemento grafico
 *  (actualiza tambien las coordenadas del centro)
 */
void ElementoGraf::moverA(int x, int y)
{
    posX = x;
    posY = y;
}

/** indicarAnchoAlto: indica el ancho y el alto del
 *  elemento grfico, para que se pueda calcular colisiones
 */
void ElementoGraf::indicarAnchoAlto(int an, int al)
{
    anchura = an;
    altura = al;
}

/** leerX: devuelve la coordenada X de la posicion
 */
int ElementoGraf::leerX()
{
    return posX;
}

/** leerY: devuelve la coordenada Y de la posicion
 */
int ElementoGraf::leerY()
{
    return posY;
}

/** leerAnchura: devuelve la anchura del elemento grafico
 */
int ElementoGraf::leerAnchura()
{
    return anchura;
}

/** leerAltura: devuelve la altura del elemento grafico
 */
int ElementoGraf::leerAltura()
{
    return altura;
}


/** leerImagen: devuelve la imagen (bitmap) del elemento grafico
 */
BITMAP* ElementoGraf::leerImagen()
{
    return imagen;
}

/** crearDesdeFichero: lee desde fichero el bitmap, y actualiza
 *  su anchura y altura
 */
void ElementoGraf::crearDesdeFichero(char *nombre)
{
    imagen = load_bmp(nombre, NULL);
    if (!imagen) {
        set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
        allegro_message("No se ha podido abrir la imagen\n");
        exit( 1 );
    }
}



/** colisionCon: devuelve si hay colision del ElementoGraf con otro
 */
bool ElementoGraf::colisionCon(ElementoGraf e2)
{
    return colisionCon(e2.posX, e2.posY, e2.anchura, e2.altura);
}


/** colisionCon: devuelve si hay colision del ElementoGraf con
 *  un rectangulo dado por sus coordenadas
 */
bool ElementoGraf::colisionCon(int x, int y, int ancho, int alto)
{
    if ((this->posX+this->anchura > x)
        && (this->posY+this->altura > y)
        && (x+ancho > this->posX)
        && (y+alto > this->posY))
      return true;
    else
      return false;
}
