/*------------------------------*/
/*  Intro a la programac de     */
/*  juegos, por Nacho Cabanes   */
/*                              */
/*   Hardware.cpp:              */
/*     Clase "Hardware"         */
/*       para Allegro           */
/*     Fichero de desarrollo    */
/*                              */
/*     Parte de "MiniMiner"     */
/*                              */
/*  Ejemplo:                    */
/*    Primer acercamiento a     */
/*    "MiniMiner"               */
/*                              */
/*  Comprobado con:             */
/*  - DevC++ 4.9.9.2(gcc 3.4.2) */
/*    y Allegro 4.03 - WinXP    */
/*------------------------------*/

#include "Hardware.h"
#include "ElementoGraf.h"
#include "iostream"

#ifdef __cplusplus
    #include <cstdlib>
#else
    #include <stdlib.h>
#endif

#include <math.h>
#include <string>

#include <allegro.h>

void Hardware::inicializar(int ancho, int alto)
{

    cout << "hard-ctor";
    allegro_init();        // Inicializamos Allegro
    install_keyboard();
    install_timer();

    anchoPantalla = ancho;
    altoPantalla = alto;

                           // Intentamos entrar a modo grafico
    set_color_depth(32);
    if (set_gfx_mode(GFX_SAFE, ancho, alto, 0, 0) != 0) {
        set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
        allegro_message(
            "Incapaz de entrar a modo grafico\n%s\n",
            allegro_error);
        exit( 1 );
    }
    
    // Pantalla oculta para evitar parpadeos
    // (doble buffer)
    pantallaOculta = create_bitmap(ancho, alto);


}


/** teclaPulsada: devuelve TRUE si alguna tecla
 *  ha sido pulsada
 */
bool Hardware::algunaTeclaPulsada()
{
    return keypressed();
}


/** comprobarTecla: devuelve TRUE si una cierta tecla
 *  ha sido pulsada
 */
bool Hardware::comprobarTecla(int codigoTecla)
{
      return key[codigoTecla];
}


/** esperarTecla: pausa hasta que se pulse una tecla,
 *  devuelve el codigo de tecla pulsada
 */
int Hardware::esperarTecla()
{
    return readkey() >> 8;
}




void Hardware::borrarOculta()
{
    // Borrar pantalla de fondo
    clear_bitmap(pantallaOculta);
}


void Hardware::dibujarOculta(ElementoGraf e)
{
    draw_sprite( pantallaOculta, e.leerImagen(), e.leerX(), e.leerY() );
}



void Hardware::visualizarOculta()
{
    // Sincronizo con el barrido para evitar parpadeos
    // y vuelco la pantalla oculta
    vsync();
    blit(pantallaOculta, screen, 0, 0, 0, 0,
      anchoPantalla, altoPantalla);
}


void Hardware::pausa(long ms)
{
    rest(ms);
}

