#include "NivelJuego.h"
#include <stdlib.h>
#include <iostream>

/** constructor: prefija a 1 el nivel de juego actual
 */
NivelJuego::NivelJuego()
{
  nivelActual = 1;
}

/** inicializar: crea los ladrillos a partir de su imagen
 *  segun el tipo de ladrillo del que se trate, prepara
 *  la pantalla vacia y llama a "leerNivel"
 */
void NivelJuego::inicializar()
{
    Pantalla::inicializar();

    ladrillo.crearDesdeFichero("data\\ladrillo4.bmp");
    ladrillo2.crearDesdeFichero("data\\ladrillo3.bmp");
    ladrillo3.crearDesdeFichero("data\\ladrillo2.bmp");
    ladrillo4.crearDesdeFichero("data\\ladrillo.bmp");
    ladrillo9.crearDesdeFichero("data\\ladrillo9.bmp");

    marcoXmin = 60;
    marcoXmax = 800;
    marcoYmin = 96;
    marcoYmax = 530;


    // Primero asigno valores inciales
    for (int j=0; j<13;j++)   {
        for (int i=0; i<13;i++)   {
          datosLadrillos[i][j].x = 120+j*25;
          datosLadrillos[i][j].y = 110+i*32;
          datosLadrillos[i][j].anchura = ladrillo.anchura;
          datosLadrillos[i][j].altura = ladrillo.altura;
          // En principio, sin ladrillos
          datosLadrillos[i][j].tipoLadrillo = 0;
        }
    }

    leerNivel();
}


/** leerNivel: lee de fichero los datos del nivel actual
 */
void NivelJuego::leerNivel()
{
    for (int j=0; j<13;j++)
        for (int i=0; i<13;i++)
          datosLadrillos[i][j].tipoLadrillo = 0;
    // Si hay fichero de datos, lo leo
    FILE *fichDatos;
    char linea[30];
    char nombreFich[50];
    sprintf(nombreFich, "data\\nivel%03d.dat", nivelActual);
    //sprintf(nombreFich, "data\\nivel001.dat", nivelActual);
    fichDatos = fopen(nombreFich, "rt"); //### Mas adelante: creciente
    if (fichDatos != NULL)
        for (int j=0; j<13;j++)   {
            fgets(linea,20,fichDatos);
            for (int i=0; i<13;i++)   {
              if (linea[i] > '0')
                datosLadrillos[j][i].tipoLadrillo = linea[i]-'0';
            }
        }

    else
    // Si no hay datos, asigno al azar
        for (int j=0; j<13;j++)   {
            for (int i=0; i<13;i++)   {
              datosLadrillos[i][j].tipoLadrillo = rand() % 2;
            }
        }

}



/** dibujar: muestra los ladrillos sobre el fondo
 *  de pantalla, con su imagen correspondiente
 *  segun el tipo de ladrillo del que se trate
 */
void NivelJuego::dibujar(Hardware h1)
{
    Pantalla::dibujar(h1);
    h = h1;

    for (int j=0; j<13;j++)
        for (int i=0; i<13;i++)
          if (datosLadrillos[i][j].tipoLadrillo > 0) {
            switch(datosLadrillos[i][j].tipoLadrillo) {
            case 1:
              ladrillo.moverA(datosLadrillos[i][j].x,
                datosLadrillos[i][j].y);
              h1.dibujarOculta(ladrillo); break;
            case 2:
              ladrillo2.moverA(datosLadrillos[i][j].x,
                datosLadrillos[i][j].y);
              h1.dibujarOculta(ladrillo2); break;
            case 3:
              ladrillo3.moverA(datosLadrillos[i][j].x,
                datosLadrillos[i][j].y);
              h1.dibujarOculta(ladrillo3); break;
            case 4:
              ladrillo4.moverA(datosLadrillos[i][j].x,
                datosLadrillos[i][j].y);
              h1.dibujarOculta(ladrillo4); break;
            case 9:
              ladrillo9.moverA(datosLadrillos[i][j].x,
                datosLadrillos[i][j].y);
              h1.dibujarOculta(ladrillo9); break;

            }
          }
}


/** comprobarColision: mira si un cierto ElementoGraf
 *  (la pelota) choca con alguno de los ladrillos.
 *  Devuelve un entero, que es la puntuacion asociada
 *  a esa colision (0 si no hay ninguna)
 */
int NivelJuego::comprobarColision(ElementoGraf p)
{
    // Comprobar si hay algn ladrillo en x, x+ancho, y, y+alto
    // Si es as, habra que borrar el ladrillo y cambiar incrementos
    // para que la pelota "rebote"
    // Devuelve 0 si no rebota; la puntuacion si rebota
    int colision = 0;
    int xL, yL, anchoL, altoL;  // Por legibilidad
    for (int j=0; j<13;j++)
        for (int i=0; i<13;i++)
          if (datosLadrillos[i][j].tipoLadrillo > 0) {
            // Variables auxiliares, por legibilidad
            xL = datosLadrillos[i][j].x;
            yL = datosLadrillos[i][j].y;
            anchoL = datosLadrillos[i][j].anchura;
            altoL = datosLadrillos[i][j].altura;

            if (p.colisionCon(xL, yL,
                 anchoL, altoL)) {
               h.reprSonidoLadrillo();
               // La puntuacion depende del tipo de ladrillo
               colision += 10*datosLadrillos[i][j].tipoLadrillo;
               //if (abs(xL-p.leerX()) < (anchoL) / 2)
               // Rebote: si la distancia en horizontal entre centros es
               // menor que la vertical, rebote horizontal
               /*
               char frase[200];
               sprintf(frase,"h:%d v:%d",abs(xL+anchoL/2 - p.centroX),
                   abs(yL+altoL/2 - p.centroY -4));
                h.escribirConsola(frase);
                */

               if (abs(xL+anchoL/2 - p.centroX) >
                   abs(yL+altoL/2 - p.centroY +2))
                 tipoRebote = REBOTEHORIZONTAL;
               else
                 tipoRebote = REBOTEVERTICAL;
               //anguloChoque = p.anguloCon(xL, yL,anchoL, altoL);
               //std::cout << anguloChoque << "\n";
               //anguloRebote =
               // El ladrillo 9 se convierte en otros
               if (datosLadrillos[i][j].tipoLadrillo==9)
                 datosLadrillos[i][j].tipoLadrillo = rand()%3+1;
               // Si es otro ladrillo, se borra
               else
                 datosLadrillos[i][j].tipoLadrillo = 0; // Borro ladrillo

              }
        }

    return colision;
}


/** quedanLadrillos: devuelve "true" si todavia queda
 *  algun ladrillo en el nivel actual (usado para
 *  saber cuando cambiar de pantalla)
 */
bool NivelJuego::quedanLadrillos()
{
    int encontrado = false;
    for (int j=0; j<13;j++)
        for (int i=0; i<13;i++)
          if (datosLadrillos[i][j].tipoLadrillo > 0)
            encontrado = true;

    return encontrado;
}
