/*------------------------------*/
/*  Intro a la programac de     */
/*  juegos, por Nacho Cabanes   */
/*                              */
/*    miner04.cpp               */
/*                              */
/*  Ejemplo:                    */
/*   "MiniMiner" (version 0.04) */
/*                              */
/*  Comprobado con:             */
/*  - DevC++ 4.9.9.2(gcc 3.4.2) */
/*    y Allegro 4.03 - WinXP    */
/*  - gcc 4.4.3 y Allegro 4.2   */
/*    en Ubuntu Linux 10.04     */
/*------------------------------*/

#include "Hardware.h"
#include "ElementoGraf.h"
#include "Personaje.h"
#include "Enemigo.h"
#include "Presentacion.h"
#include "Nivel.h"

/* -------------- Constantes globales ------------- */
#define ANCHOPANTALLA 640
#define ALTOPANTALLA 480

/* -------------- Variables globales -------------- */
Hardware hard;
Personaje *personaje;
Enemigo *enemigo;
Presentacion *presentacion;
Nivel *primerNivel;

int partidaTerminada;
int incrX = 4;
int incrY = 4;
int tecla;
int ySuelo = 232;


// Prototipos de las funciones que usaremos
void comprobarTeclas();
void moverElementos();
void comprobarColisiones();
void dibujarElementos();
void pausaFotograma();
void moverDerecha();
void moverIzquierda();
void lanzarPresentacion();
void moverEnemigo();
void dibujarFondo();



// --- Bucle principal del juego -----
void buclePrincipal() {
  partidaTerminada = false;
  do {
    comprobarTeclas();
    moverElementos();
    comprobarColisiones();
    dibujarElementos();
    pausaFotograma();
  } while (partidaTerminada != true);
}


// -- Comprobac de teclas para mover personaje o salir
void comprobarTeclas() {   

  if (hard.comprobarTecla(TECLA_ESC))
     partidaTerminada = true;

  if (hard.comprobarTecla(TECLA_DCHA))
     personaje->moverDerecha();
  else if (hard.comprobarTecla(TECLA_IZQD))
     personaje->moverIzquierda();
}


// -- Mover otros elementos del juego 
void moverElementos() {
  enemigo->mover();
}


// -- Comprobar colisiones de nuestro elemento con otros, o disparos con enemigos, etc
void comprobarColisiones() {
  
}


// -- Dibujar elementos en pantalla
void dibujarElementos() {

  hard.borrarOculta();
  primerNivel->dibujarOculta(hard);
  hard.dibujarOculta( *enemigo );
  hard.dibujarOculta( *personaje );
  hard.visualizarOculta();
}


// -- Pausa hasta el siguiente fotograma
void pausaFotograma() {
  // Para 25 fps: 1000/25 = 40 milisegundos de pausa
  hard.pausa(40);
}


// -- Funciones que no son de la logica de juego, sino de 
// funcionamiento interno de otros componentes

// -- Pantalla de presentacion
void lanzarPresentacion() {
  presentacion->mostrar(hard);
}


/* -------------- Rutina de inicializacin -------- */
int inicializa()
{
    hard.inicializar(640,480);
    personaje = new Personaje();
    enemigo = new Enemigo();
    presentacion = new Presentacion();
    primerNivel = new Nivel();

   // Y termino indicando que no ha habido errores
   return 0;
}



/* ------------------------------------------------ */
/*                                                  */
/* -------------- Cuerpo del programa ------------- */

int main()
{
    int i,j;

    // Intento inicializar
    if (inicializa() != 0)
        exit(1);
        
    lanzarPresentacion();
    buclePrincipal();

    hard.pausa(1000);
    return 0;
}

            /* Termino con la "macro" que me pide Allegro */
END_OF_MAIN();
